/**
 * Visual Blocks Language
 *
 * Copyright 2012 Google Inc.
 * http://blockly.googlecode.com/
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 * @fileoverview Generating JavaScript for text blocks.
 * @author fraser@google.com (Neil Fraser)
 */
'use strict';

//2013/03/10 my create line start
goog.provide('Blockly.JavaScript.playground');

goog.require('Blockly.JavaScript');


// playground(遊び場)画面オブジェクト(キャンバス)設定
Blockly.JavaScript.playground = function() {
  // playground オブジェクトの変数名 -> '_playgroundCanvasVar_'
  // playground キャンバスのID -> 'area_playground'

  // playground 画面オブジェクトへの背景色設定
  var background_color = this.getTitleValue('MODE');
  var code = "_playgroundCanvasVar_.style['background-color'] = '"+background_color+"';\n"
           + "_pg_context_.fillStyle = _playgroundCanvasVar_.style['background-color'];\n"
           + "_pg_context_.fillRect(0,0, 700,400);\n";
  Blockly.JavaScript.playground.isExist = true;

  //playgroud 画面での処理設定
  var branch = Blockly.JavaScript.statementToCode(this, 'DO');
  code += branch;
  return code;
};

// playground 定義確認フラグ
Blockly.JavaScript.playground.isExist = null;
// playground 初期設定コード
Blockly.JavaScript.playground.initCode = "var _playgroundCanvasVar_ = document.getElementById('area_playground');\n"
                                       + "var _pg_context_ = _playgroundCanvasVar_.getContext('2d');";



// playground(遊び場)の doroid(アイコン表示物)設定
Blockly.JavaScript.playground_doroid = function() {
  // ドロイドくんアイコン設定
  var argument0 = Blockly.JavaScript.valueToCode(this, 'POS_X',
      Blockly.JavaScript.ORDER_ASSIGNMENT) || '0';
  var argument1 = Blockly.JavaScript.valueToCode(this, 'POS_Y',
      Blockly.JavaScript.ORDER_ASSIGNMENT) || '0';
  Blockly.JavaScript.playground_doroid.isExist = true;

  var code;
  code = "if (_playgroundCanvasVar_) {\n"
       + "  var _pg_context_ = _playgroundCanvasVar_.getContext('2d');\n"
       + "  _pg_context_.fillStyle = _playgroundCanvasVar_.style['background-color'];\n"
       + "  _pg_context_.fillRect(_doroidImageX_,_doroidImageY_, 36,44);\n"
       + "  _doroidImageX_ = " + argument0 + ";\n"
       + "  _doroidImageY_ = " + argument1 + ";\n"
       + "  _pg_context_.drawImage(_doroidImageVar_, _doroidImageX_,_doroidImageY_, 36,44);\n"
       + "}\n";
  return code;
};

// doroid 定義確認フラグ
Blockly.JavaScript.playground_doroid.isExist = null;
// doroid 初期設定コード
Blockly.JavaScript.playground_doroid.initCode = "var _doroidImageVar_ = new Image();\n" + "_doroidImageVar_.src = 'doroid.png';\n"
                                              + "var _doroidImageX_ = 0;\n" + "var _doroidImageY_ = 0;";



// playground(遊び場)での wait(待機時間)設定
Blockly.JavaScript.playground_wait = function() {
  // 待機時間(ミリ秒)設定
  var waitTime = Number(this.getTitleValue('TIME'));
  // 待機後に呼び出す関数
  var branch = Blockly.JavaScript.statementToCode(this, 'FUNC');
  branch = branch.substring(0, branch.indexOf(';')).replace(/^ +/,"");

  var code = "setTimeout(function(){" + branch + ";}, " + waitTime + ");\n";
  return code;
};
//2013/03/10 my create line end

