/**
 * Visual Blocks Language
 *
 * Copyright 2012 Google Inc.
 * http://blockly.googlecode.com/
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 * @fileoverview Text blocks for Blockly.
 * @author fraser@google.com (Neil Fraser)
 */
'use strict';

//2013/03/10 my create line start
goog.provide('Blockly.Language.playground');

goog.require('Blockly.Language');

// playground(遊び場)画面のブロック設定
Blockly.Language.playground = {
  // Playground screen setting.
  helpUrl: Blockly.LANG_PLAYGROUND_PLAYGROUND_HELPURL,
  init: function() {
    //ブロック色設定(引数はHSV色)
    this.setColour(100);
    //作業変数の値を設定する、入力フィールド(リストボックス等)を追加
    //【注】入力フィールドは、必須ではありません。(指定しなくてもでも良い)
    this.appendDummyInput()
        .appendTitle(Blockly.LANG_PLAYGROUND_PLAYGROUND_TITLE)
        .appendTitle(new Blockly.FieldDropdown(this.OPERATORS), 'MODE');
    //実行処理内容(プログラム・コートテキスト)を設定する、入力ブロック行を追加
    this.appendStatementInput('DO')
        .appendTitle(Blockly.LANG_PLAYGROUND_PLAYGROUND_INPUT_DO);
    //前ブロック受付指定(有効)
    this.setPreviousStatement(true);
    //次ブロック受付指定(有効)
    this.setNextStatement(true);
    //ツールチップ表示指定
    this.setTooltip(Blockly.LANG_PLAYGROUND_PLAYGROUND_TOOLTIP);
  }
};

Blockly.Language.playground.OPERATORS =
    [['black',   '#000'],
     ['silver',  '#ccc'],
     ['gray',    '#888'],
     ['white',   '#fff'],
     ['maroon',  '#800'],
     ['red',     '#f00'],
     ['purple',  '#808'],
     ['funchsia','#f0f'],
     ['green',   '#080'],
     ['lime',    '#0f0'],
     ['olive',   '#880'],
     ['yellow',  '#ff0'],
     ['navy',    '#008'],
     ['blue',    '#00f'],
     ['teal',    '#088'],
     ['aqua',    '#0ff']];


// playground(遊び場)画面の doroido(アイコン表示)ブロック設定
Blockly.Language.playground_doroid = {
  // ドロイドくんアイコン設定
  helpUrl: Blockly.LANG_PLAYGROUND_DOROID_HELPURL,
  init: function() {
    //ブロック色設定(引数はHSV色)
    this.setColour(100);
    //作業変数の値を設定する、入力フィールド(リストボックス等)を追加
    //【注】入力フィールドは、必須ではありません。(指定しなくてもでも良い)
    this.appendDummyInput()
        .appendTitle(Blockly.LANG_PLAYGROUND_DOROID_INPUT_ICON)
        .appendTitle(new Blockly.FieldImage('doroid.png', 36, 44));
    //作業変数の値を設定する、入力ブロック行を追加
    this.appendValueInput('POS_X')
        .setCheck(Number)
        .setAlign(Blockly.ALIGN_RIGHT)
        .appendTitle(Blockly.LANG_PLAYGROUND_DOROID_INPUT_X);
    //作業変数の値を設定する、入力ブロック行を追加
    this.appendValueInput('POS_Y')
        .setCheck(Number)
        .setAlign(Blockly.ALIGN_RIGHT)
        .appendTitle(Blockly.LANG_PLAYGROUND_DOROID_INPUT_Y);
    //前ブロック受付指定(有効)
    this.setPreviousStatement(true);
    //前ブロック受付指定(有効)
    this.setNextStatement(true);
    //入力項目のインライン指定(あり)
    //【注】入力フィールドと入力ブロックが複数ある場合、
    //     true 指定により、それらを１行に表示します。
    this.setInputsInline(true);

    //ツールチップ表示指定
    // Assign 'this' to a variable for use in the tooltip closure below.
    var thisBlock = this;
    this.setTooltip(function() {
      return Blockly.LANG_PLAYGROUND_DOROID_TOOLTIP.replace('%1',
          thisBlock.getTitleValue('VAR'));
    });
  },
  //以降は、
  //参考にした Blockly.Language.controls_for の設定内容のままです。
  getVars: function() {
    return [this.getTitleValue('VAR')];
  },
  renameVar: function(oldName, newName) {
    if (Blockly.Names.equals(oldName, this.getTitleValue('VAR'))) {
      this.setTitleValue(newName, 'VAR');
    }
  },
  customContextMenu: function(options) {
    var option = {enabled: true};
    var name = this.getTitleValue('VAR');
    option.text = Blockly.LANG_VARIABLES_SET_CREATE_GET.replace('%1', name);
    option.callback = Blockly.ContextMenu.callbackFactory(this,
        'variables_get', 'VAR', name);
    options.push(option);
  }
};


// playground(遊び場)画面の wait(待機時間)ブロック設定
Blockly.Language.playground_wait = {
  // 待機時間設定
  helpUrl: Blockly.LANG_PLAYGROUND_WAIT_HELPURL,
  init: function() {
    //ブロック色設定(引数はHSV色)
    this.setColour(100);
    //作業変数の値を設定する、入力フィールド(リストボックス等)を追加
    //【注】入力フィールドは、必須ではありません。(指定しなくてもでも良い)
    this.appendDummyInput()
        .appendTitle(Blockly.LANG_PLAYGROUND_WAIT_TITLE)
        .appendTitle(new Blockly.FieldTextInput('1000',
            Blockly.FieldTextInput.nonnegativeIntegerValidator), 'TIME')
        .appendTitle(Blockly.LANG_PLAYGROUND_WAIT_TITLE_TIME);
    //実行処理内容(プログラム・コートテキスト)を設定する、入力ブロック行を追加
    this.appendStatementInput('FUNC')
        .appendTitle(Blockly.LANG_PLAYGROUND_WAIT_INPUT_FUNC);
    //前ブロック受付指定(有効)
    this.setPreviousStatement(true);
    //前ブロック受付指定(有効)
    this.setNextStatement(true);
    //ツールチップ表示指定
    this.setTooltip(Blockly.LANG_PLAYGROUND_WAIT_TOOLTIP);
  }
};
//2013/03/10 my create line end

